@@ -7,7 +7,7 @@
 
 #include "kaboutapplicationpersonlistdelegate_p.h"
 
-#include "kaboutapplicationpersonlistview_p.h"
+#include "kaboutapplicationlistview_p.h"
 #include "kaboutapplicationpersonmodel_p.h"
 #include "ktoolbar.h"
 
@@ -70,7 +70,7 @@ QList<QWidget *> KAboutApplicationPersonListDelegate::createItemWidgets(const QM
     return list;
 }
 
-void KAboutApplicationPersonListDelegate::updateItemWidgets(const QList<QWidget *> widgets,
+void KAboutApplicationPersonListDelegate::updateItemWidgets(const QList<QWidget *> &widgets,
                                                             const QStyleOptionViewItem &option,
                                                             const QPersistentModelIndex &index) const
 {
@@ -95,7 +95,7 @@ void KAboutApplicationPersonListDelegate::updateItemWidgets(const QList<QWidget
 
     label->setText(text);
 
-    // And now we fill in the main links (email + homepage + OCS profile)...
+    // And now we fill in the main links (email + homepage)
     KToolBar *mainLinks = qobject_cast<KToolBar *>(widgets.at(MainLinks));
     mainLinks->setIconSize(QSize(22, 22));
     mainLinks->setContentsMargins(0, 0, 0, 0);
@@ -113,13 +113,6 @@ void KAboutApplicationPersonListDelegate::updateItemWidgets(const QList<QWidget
         action->setData(profile.homepage().toString());
         action->setVisible(true);
     }
-    if (!profile.ocsProfileUrl().isEmpty()) {
-        action = mainLinks->actions().at(VisitProfileAction);
-        KAboutApplicationPersonModel *model = qobject_cast<KAboutApplicationPersonModel *>(itemView()->model());
-        action->setToolTip(i18nc("@info:tooltip", "Visit contributor's profile on %1\n%2", model->providerName(), profile.ocsProfileUrl()));
-        action->setData(profile.ocsProfileUrl());
-        action->setVisible(true);
-    }
     mainLinks->resize(QSize(mainLinks->sizeHint().width(), MAIN_LINKS_HEIGHT));
     mainLinks->move(wRect.left(), wRect.top() + label->height());
     itemView()->reset();
@@ -222,3 +215,5 @@ QRect KAboutApplicationPersonListDelegate::widgetsRect(const QStyleOptionViewIte
 }
 
 } // namespace KDEPrivate
+
+#include "moc_kaboutapplicationpersonlistdelegate_p.cpp"
