@@ -15,13 +15,13 @@
 #ifndef KACTIONCOLLECTION_H
 #define KACTIONCOLLECTION_H
 
+#include <KStandardAction>
 #include <kxmlgui_export.h>
-#include <kstandardaction.h>
 
-#include <QObject>
 #include <QAction>
+#include <QObject>
+#include <memory>
 
-class QAction;
 class KXMLGUIClient;
 class KConfigGroup;
 class QActionGroup;
@@ -133,48 +133,48 @@ public:
     void setConfigGlobal(bool global);
 
     /**
-      * Read all key associations from @p config.
-      *
-      * If @p config is zero, read all key associations from the
-      * application's configuration file KSharedConfig::openConfig(),
-      * in the group set by setConfigGroup().
-      */
+     * Read all key associations from @p config.
+     *
+     * If @p config is zero, read all key associations from the
+     * application's configuration file KSharedConfig::openConfig(),
+     * in the group set by setConfigGroup().
+     */
     void readSettings(KConfigGroup *config = nullptr);
 
     /**
-      * Import from @p config all configurable global key associations.
-      *
-      * \since 4.1
-      *
-      * \param config Config object to read from
-      */
+     * Import from @p config all configurable global key associations.
+     *
+     * \since 4.1
+     *
+     * \param config Config object to read from
+     */
     void importGlobalShortcuts(KConfigGroup *config);
 
     /**
-      * Export the current configurable global key associations to @p config.
-      *
-      * \since 4.1
-      *
-      * \param config Config object to save to
-      * \param writeDefaults set to true to write settings which are already at defaults.
-      */
+     * Export the current configurable global key associations to @p config.
+     *
+     * \since 4.1
+     *
+     * \param config Config object to save to
+     * \param writeDefaults set to true to write settings which are already at defaults.
+     */
     void exportGlobalShortcuts(KConfigGroup *config, bool writeDefaults = false) const;
 
     /**
-      * Write the current configurable key associations to @p config. What the
-      * function does if @p config is zero depends. If this action collection
-      * belongs to a KXMLGUIClient the setting are saved to the kxmlgui
-      * definition file. If not the settings are written to the applications
-      * config file.
-      *
-      * \note @p oneAction and @p writeDefaults have no meaning for the kxmlgui
-      * configuration file.
-      *
-      * \param config Config object to save to, or null (see above)
-      * \param writeDefaults set to true to write settings which are already at defaults.
-      * \param oneAction pass an action here if you just want to save the values for one action, eg.
-      *                  if you know that action is the only one which has changed.
-      */
+     * Write the current configurable key associations to @p config. What the
+     * function does if @p config is zero depends. If this action collection
+     * belongs to a KXMLGUIClient the setting are saved to the kxmlgui
+     * definition file. If not the settings are written to the applications
+     * config file.
+     *
+     * \note @p oneAction and @p writeDefaults have no meaning for the kxmlgui
+     * configuration file.
+     *
+     * \param config Config object to save to, or null (see above)
+     * \param writeDefaults set to true to write settings which are already at defaults.
+     * \param oneAction pass an action here if you just want to save the values for one action, eg.
+     *                  if you know that action is the only one which has changed.
+     */
     void writeSettings(KConfigGroup *config = nullptr, bool writeDefaults = false, QAction *oneAction = nullptr) const;
 
     /**
@@ -199,11 +199,19 @@ public:
     /**
      * Get the action with the given \p name from the action collection.
      *
+     * This won't return the action for the menus defined using a "<Menu>" tag
+     * in XMLGUI files (e.g. "<Menu name="menuId">" in "applicationNameui.rc").
+     * To access menu actions defined like this, use e.g.
+     * \code
+     * qobject_cast<QMenu *>(guiFactory()->container("menuId", this));
+     * \endcode
+     * after having called setupGUI() or createGUI().
+     *
      * @param name Name of the QAction
      * @return A pointer to the QAction in the collection which matches the parameters or
      * null if nothing matches.
      */
-    QAction *action(const QString &name) const;
+    Q_INVOKABLE QAction *action(const QString &name) const;
 
     /**
      * Returns the list of QActions which belong to this action collection.
@@ -259,30 +267,12 @@ Q_SIGNALS:
      */
     void inserted(QAction *action);
 
-#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * Indicates that @p action was removed from this action collection.
-     * @deprecated Since 5.0, use changed() (added in 5.66) instead.
-     */
-    KXMLGUI_DEPRECATED_VERSION(5, 0, "removed() is sometimes emitted with partially destroyed objects; use changed() instead (added in 5.66)")
-    QT_MOC_COMPAT void removed(QAction *action);
-#endif
-
     /**
      * Emitted when an action has been inserted into, or removed from, this action collection.
      * @since 5.66
      */
     void changed();
 
-#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * Indicates that @p action was highlighted (hovered over).
-     * @deprecated Since 5.0. Replaced by actionHovered(QAction* action);
-     */
-    KXMLGUI_DEPRECATED_VERSION(5, 0, "Use KActionCollection::actionHovered(QAction* action)")
-    QT_MOC_COMPAT void actionHighlighted(QAction *action);
-#endif
-
     /**
      * Indicates that @p action was hovered.
      */
@@ -300,17 +290,8 @@ protected:
 protected Q_SLOTS:
     virtual void slotActionTriggered();
 
-#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * @internal
-     * @deprecated Since 5.0. Replaced by slotActionHovered();
-     */
-    KXMLGUI_DEPRECATED_VERSION(5, 0, "Use KActionCollection::slotActionHovered()")
-    QT_MOC_COMPAT virtual void slotActionHighlighted();
-#endif
-
 private Q_SLOTS:
-    void slotActionHovered();
+    KXMLGUI_NO_EXPORT void slotActionHovered();
 
 public:
     /**
@@ -411,8 +392,34 @@ public:
      *               connection is desired.
      * @return new action of the given type ActionType.
      */
-    QAction *addAction(KStandardAction::StandardAction actionType, const QString &name,
-                       const QObject *receiver = nullptr, const char *member = nullptr);
+    QAction *addAction(KStandardAction::StandardAction actionType, const QString &name, const QObject *receiver = nullptr, const char *member = nullptr);
+
+/**
+ * This is the same as addAction(KStandardAction::StandardAction actionType, const QString &name, const QObject *receiver, const char *member) using
+ * new style connect syntax.
+ *
+ * @param actionType The standard action type of the action to create.
+ * @param name The name by which the action be retrieved again from the collection.
+ * @param receiver The QObject to connect the triggered(bool) signal to.
+ * @param slot The slot or lambda to connect the triggered(bool) signal to.
+ * @return new action of the given type ActionType.
+ *
+ * @see addAction(KStandardAction::StandardAction, const QString &, const QObject *, const char *)
+ * @since 5.80
+ */
+#ifdef K_DOXYGEN
+    inline QAction *addAction(KStandardAction::StandardAction actionType, const QString &name, const Receiver *receiver, Func slot)
+#else
+    template<class Receiver, class Func>
+    inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *
+    addAction(KStandardAction::StandardAction actionType, const QString &name, const Receiver *receiver, Func slot)
+#endif
+    {
+        QAction *action = KStandardAction::create(actionType, receiver, slot, nullptr);
+        action->setParent(this);
+        action->setObjectName(name);
+        return addAction(name, action);
+    }
 
     /**
      * Creates a new action under the given name to the collection and connects
@@ -471,26 +478,26 @@ public:
         return a;
     }
 
-    /**
-     * This is the same as add(const QString &name, const QObject *receiver, const char *member) using
-     * new style connect syntax.
-     *
-     * @param name The internal name of the action (e.g. "file-open").
-     * @param receiver The QObject to connect the triggered(bool) signal to.
-     * @param slot The slot or lambda to connect the triggered(bool) signal to.
-     * @return new action of the given type ActionType.
-     *
-     * @see add(const QString &, const QObject *, const char *)
-     * @since 5.28
-     */
-    #ifdef K_DOXYGEN
+/**
+ * This is the same as add(const QString &name, const QObject *receiver, const char *member) using
+ * new style connect syntax.
+ *
+ * @param name The internal name of the action (e.g. "file-open").
+ * @param receiver The QObject to connect the triggered(bool) signal to.
+ * @param slot The slot or lambda to connect the triggered(bool) signal to.
+ * @return new action of the given type ActionType.
+ *
+ * @see add(const QString &, const QObject *, const char *)
+ * @since 5.28
+ */
+#ifdef K_DOXYGEN
     template<class ActionType>
     inline ActionType *add(const QString &name, const Receiver *receiver, Func slot)
-    #else
+#else
     template<class ActionType, class Receiver, class Func>
-    inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, ActionType>::type *add(
-        const QString &name, const Receiver *receiver, Func slot)
-    #endif
+    inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, ActionType>::type *
+    add(const QString &name, const Receiver *receiver, Func slot)
+#endif
     {
         ActionType *a = new ActionType(this);
         connect(a, &QAction::triggered, receiver, slot);
@@ -498,25 +505,25 @@ public:
         return a;
     }
 
-    /**
-     * This is the same as addAction(const QString &name, const QObject *receiver, const char *member) using
-     * new style connect syntax.
-     *
-     * @param name The internal name of the action (e.g. "file-open").
-     * @param receiver The QObject to connect the triggered(bool) signal to.
-     * @param slot The slot or lambda to connect the triggered(bool) signal to.
-     * @return new action of the given type ActionType.
-     *
-     * @see addAction(const QString &, const QObject *, const char *)
-     * @since 5.28
-     */
-    #ifdef K_DOXYGEN
+/**
+ * This is the same as addAction(const QString &name, const QObject *receiver, const char *member) using
+ * new style connect syntax.
+ *
+ * @param name The internal name of the action (e.g. "file-open").
+ * @param receiver The QObject to connect the triggered(bool) signal to.
+ * @param slot The slot or lambda to connect the triggered(bool) signal to.
+ * @return new action of the given type ActionType.
+ *
+ * @see addAction(const QString &, const QObject *, const char *)
+ * @since 5.28
+ */
+#ifdef K_DOXYGEN
     inline QAction *addAction(const QString &name, const Receiver *receiver, Func slot)
-    #else
+#else
     template<class Receiver, class Func>
-    inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *addAction(
-        const QString &name, const Receiver *receiver, Func slot)
-    #endif
+    inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *
+    addAction(const QString &name, const Receiver *receiver, Func slot)
+#endif
     {
         return add<QAction>(name, receiver, slot);
     }
@@ -528,7 +535,7 @@ public:
      * @return the default primary shortcut of the given action
      * @since 5.0
      */
-    QKeySequence defaultShortcut(QAction *action) const;
+    static QKeySequence defaultShortcut(QAction *action);
 
     /**
      * Get the default shortcuts for the given action.
@@ -537,9 +544,8 @@ public:
      * @return the default shortcuts of the given action
      * @since 5.0
      */
-    QList<QKeySequence> defaultShortcuts(QAction *action) const;
+    static QList<QKeySequence> defaultShortcuts(QAction *action);
 
-    //TODO KF6: Make setDefaultShortcut static
     /**
      * Set the default shortcut for the given action.
      * Since 5.2, this also calls action->setShortcut(shortcut), i.e. the default shortcut is
@@ -549,7 +555,7 @@ public:
      * @param shortcut the shortcut to use for the given action in its specified shortcutContext()
      * @since 5.0
      */
-    void setDefaultShortcut(QAction *action, const QKeySequence &shortcut);
+    static void setDefaultShortcut(QAction *action, const QKeySequence &shortcut);
 
     /**
      * Set the default shortcuts for the given action.
@@ -560,7 +566,7 @@ public:
      * @param shortcuts the shortcuts to use for the given action in its specified shortcutContext()
      * @since 5.0
      */
-    Q_INVOKABLE void setDefaultShortcuts(QAction *action, const QList<QKeySequence> &shortcuts);
+    Q_INVOKABLE static void setDefaultShortcuts(QAction *action, const QList<QKeySequence> &shortcuts);
 
     /**
      * Returns true if the given action's shortcuts may be configured by the user.
@@ -568,7 +574,7 @@ public:
      * @param action the action for the hint should be verified.
      * @since 5.0
      */
-    bool isShortcutsConfigurable(QAction *action) const;
+    static bool isShortcutsConfigurable(QAction *action);
 
     /**
      * Indicate whether the user may configure the action's shortcuts.
@@ -577,16 +583,13 @@ public:
      * @param configurable set to true if the shortcuts of the given action may be configured by the user, otherwise false.
      * @since 5.0
      */
-    void setShortcutsConfigurable(QAction *action, bool configurable);
+    static void setShortcutsConfigurable(QAction *action, bool configurable);
 
 private:
-    Q_PRIVATE_SLOT(d, void _k_actionDestroyed(QObject *))
-    Q_PRIVATE_SLOT(d, void _k_associatedWidgetDestroyed(QObject *))
-
-    KActionCollection(const KXMLGUIClient *parent);   // used by KXMLGUIClient
+    KXMLGUI_NO_EXPORT explicit KActionCollection(const KXMLGUIClient *parent); // used by KXMLGUIClient
 
     friend class KActionCollectionPrivate;
-    class KActionCollectionPrivate *const d;
+    std::unique_ptr<class KActionCollectionPrivate> const d;
 };
 
 #endif
