@@ -52,8 +52,6 @@
 
 //#include <cctype>
 
-static const char WINDOW_PROPERTIES[] = "WindowProperties";
-
 static QMenuBar *internalMenuBar(KMainWindow *mw)
 {
     return mw->findChild<QMenuBar *>(QString(), Qt::FindDirectChildrenOnly);
@@ -101,7 +99,7 @@ bool DockResizeListener::eventFilter(QObject *watched, QEvent *event)
     case QEvent::Move:
     case QEvent::Show:
     case QEvent::Hide:
-        m_win->k_ptr->setSettingsDirty(KMainWindowPrivate::CompressCalls);
+        m_win->d_ptr->setSettingsDirty(KMainWindowPrivate::CompressCalls);
         break;
 
     default:
@@ -142,7 +140,7 @@ void KMWSessionManager::saveState(QSessionManager &sm)
         mw->savePropertiesInternal(config, n);
     }
 
-    KConfigGroup group(config, "Number");
+    KConfigGroup group(config, QStringLiteral("Number"));
     group.writeEntry("NumberOfWindows", n);
 
     // store new status to disk
@@ -202,12 +200,14 @@ void KMWSessionManager::commitData(QSessionManager &sm)
 #endif // QT_NO_SESSIONMANAGER
 }
 
+#ifndef QT_NO_SESSIONMANAGER
 Q_GLOBAL_STATIC(KMWSessionManager, ksm)
+#endif
 Q_GLOBAL_STATIC(QList<KMainWindow *>, sMemberList)
 
-KMainWindow::KMainWindow(QWidget *parent, Qt::WindowFlags f)
-    : QMainWindow(parent, f)
-    , k_ptr(new KMainWindowPrivate)
+KMainWindow::KMainWindow(QWidget *parent, Qt::WindowFlags flags)
+    : QMainWindow(parent, flags)
+    , d_ptr(new KMainWindowPrivate)
 {
     Q_D(KMainWindow);
 
@@ -216,7 +216,7 @@ KMainWindow::KMainWindow(QWidget *parent, Qt::WindowFlags f)
 
 KMainWindow::KMainWindow(KMainWindowPrivate &dd, QWidget *parent, Qt::WindowFlags f)
     : QMainWindow(parent, f)
-    , k_ptr(&dd)
+    , d_ptr(&dd)
 {
     Q_D(KMainWindow);
 
@@ -227,13 +227,6 @@ void KMainWindowPrivate::init(KMainWindow *_q)
 {
     q = _q;
 
-    // Not needed in Qt6 (and doesn't exist at all)
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#ifndef QT_NO_SESSIONMANAGER
-    QGuiApplication::setFallbackSessionManagementEnabled(false);
-#endif
-#endif
-
     q->setAnimated(q->style()->styleHint(QStyle::SH_Widget_Animate, nullptr, q));
 
     q->setAttribute(Qt::WA_DeleteOnClose);
@@ -437,62 +430,31 @@ void KMainWindowPrivate::setSizeDirty()
 KMainWindow::~KMainWindow()
 {
     sMemberList()->removeAll(this);
-    delete static_cast<QObject *>(k_ptr->dockResizeListener); // so we don't get anymore events after k_ptr is destroyed
+    delete static_cast<QObject *>(d_ptr->dockResizeListener); // so we don't get anymore events after d_ptr is destroyed
 }
 
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-QMenu *KMainWindow::helpMenu(const QString &aboutAppText, bool showWhatsThis)
-{
-    Q_D(KMainWindow);
-    if (!d->helpMenu) {
-        if (aboutAppText.isEmpty()) {
-            d->helpMenu = new KHelpMenu(this, KAboutData::applicationData(), showWhatsThis);
-        } else {
-            d->helpMenu = new KHelpMenu(this, aboutAppText, showWhatsThis);
-        }
-
-        if (!d->helpMenu) {
-            return nullptr;
-        }
-    }
-
-    return d->helpMenu->menu();
-}
-
-QMenu *KMainWindow::customHelpMenu(bool showWhatsThis)
-{
-    Q_D(KMainWindow);
-    if (!d->helpMenu) {
-        d->helpMenu = new KHelpMenu(this, QString(), showWhatsThis);
-        connect(d->helpMenu, &KHelpMenu::showAboutApplication, this, &KMainWindow::showAboutApplication);
-    }
-
-    return d->helpMenu->menu();
-}
-#endif
-
-bool KMainWindow::canBeRestored(int number)
+bool KMainWindow::canBeRestored(int numberOfInstances)
 {
     KConfig *config = KConfigGui::sessionConfig();
     if (!config) {
         return false;
     }
 
-    KConfigGroup group(config, "Number");
+    KConfigGroup group(config, QStringLiteral("Number"));
     // TODO KF6: we should use 0 as the default value, not 1
     // See also https://bugs.kde.org/show_bug.cgi?id=427552
     const int n = group.readEntry("NumberOfWindows", 1);
-    return number >= 1 && number <= n;
+    return numberOfInstances >= 1 && numberOfInstances <= n;
 }
 
-const QString KMainWindow::classNameOfToplevel(int number)
+const QString KMainWindow::classNameOfToplevel(int instanceNumber)
 {
     KConfig *config = KConfigGui::sessionConfig();
     if (!config) {
         return QString();
     }
 
-    KConfigGroup group(config, QByteArray(WINDOW_PROPERTIES).append(QByteArray::number(number)).constData());
+    KConfigGroup group(config, QStringLiteral("WindowProperties%1").arg(instanceNumber));
     if (!group.hasKey("ClassName")) {
         return QString();
     } else {
@@ -500,13 +462,13 @@ const QString KMainWindow::classNameOfToplevel(int number)
     }
 }
 
-bool KMainWindow::restore(int number, bool show)
+bool KMainWindow::restore(int numberOfInstances, bool show)
 {
-    if (!canBeRestored(number)) {
+    if (!canBeRestored(numberOfInstances)) {
         return false;
     }
     KConfig *config = KConfigGui::sessionConfig();
-    if (readPropertiesInternal(config, number)) {
+    if (readPropertiesInternal(config, numberOfInstances)) {
         if (show) {
             KMainWindow::show();
         }
@@ -608,7 +570,7 @@ void KMainWindow::savePropertiesInternal(KConfig *config, int number)
     const bool oldASWS = d->autoSaveWindowSize;
     d->autoSaveWindowSize = true; // make saveMainWindowSettings save the window size
 
-    KConfigGroup cg(config, QByteArray(WINDOW_PROPERTIES).append(QByteArray::number(number)).constData());
+    KConfigGroup cg(config, QStringLiteral("WindowProperties%1").arg(number));
 
     // store objectName, className, Width and Height  for later restoring
     // (Only useful for session management)
@@ -617,7 +579,7 @@ void KMainWindow::savePropertiesInternal(KConfig *config, int number)
 
     saveMainWindowSettings(cg); // Menubar, statusbar and Toolbar settings.
 
-    cg = KConfigGroup(config, QByteArray::number(number).constData());
+    cg = KConfigGroup(config, QString::number(number));
     saveProperties(cg);
 
     d->autoSaveWindowSize = oldASWS;
@@ -670,12 +632,11 @@ void KMainWindow::saveMainWindowSettings(KConfigGroup &cg)
     int n = 1; // Toolbar counter. toolbars are counted from 1,
     const auto toolBars = this->toolBars();
     for (KToolBar *toolbar : toolBars) {
-        QByteArray groupName("Toolbar");
         // Give a number to the toolbar, but prefer a name if there is one,
         // because there's no real guarantee on the ordering of toolbars
-        groupName += (toolbar->objectName().isEmpty() ? QByteArray::number(n) : QByteArray(" ").append(toolbar->objectName().toUtf8()));
+        const QString groupName = toolbar->objectName().isEmpty() ? QStringLiteral("Toolbar%1").arg(n) : (QStringLiteral("Toolbar ") + toolbar->objectName());
 
-        KConfigGroup toolbarGroup(&cg, groupName.constData());
+        KConfigGroup toolbarGroup(&cg, groupName);
         toolbar->saveSettings(toolbarGroup);
         n++;
     }
@@ -693,7 +654,7 @@ bool KMainWindow::readPropertiesInternal(KConfig *config, int number)
     }
 
     // in order they are in toolbar list
-    KConfigGroup cg(config, QByteArray(WINDOW_PROPERTIES).append(QByteArray::number(number)).constData());
+    KConfigGroup cg(config, QStringLiteral("WindowProperties%1").arg(number));
 
     // restore the object name (window role)
     if (cg.hasKey("ObjectName")) {
@@ -704,7 +665,7 @@ bool KMainWindow::readPropertiesInternal(KConfig *config, int number)
     // if necessary. Do it before the call to applyMainWindowSettings.
     applyMainWindowSettings(cg); // Menubar, statusbar and toolbar settings.
 
-    KConfigGroup grp(config, QByteArray::number(number).constData());
+    KConfigGroup grp(config, QString::number(number));
     readProperties(grp);
 
     d->letDirtySettings = oldLetDirtySettings;
@@ -745,10 +706,10 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &_cg)
         // Let the user opt out of KDE apps remembering window sizes if they
         // find it annoying or it doesn't work for them due to other bugs.
         KSharedConfigPtr config = KSharedConfig::openConfig();
-        KConfigGroup group(config, "General");
+        KConfigGroup group(config, QStringLiteral("General"));
         if (group.readEntry("AllowKDEAppsToRememberWindowPositions", true)) {
             if (stateConfig.readEntry("RestorePositionForNextInstance", true)) {
-                KWindowConfig::restoreWindowPosition(windowHandle(), cg);
+                KWindowConfig::restoreWindowPosition(windowHandle(), stateConfig);
                 // Save the fact that we now don't want to restore position
                 // anymore; if we did, the next instance would completely cover
                 // the existing one
@@ -777,12 +738,11 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &_cg)
     int n = 1; // Toolbar counter. toolbars are counted from 1,
     const auto toolBars = this->toolBars();
     for (KToolBar *toolbar : toolBars) {
-        QByteArray groupName("Toolbar");
         // Give a number to the toolbar, but prefer a name if there is one,
         // because there's no real guarantee on the ordering of toolbars
-        groupName += (toolbar->objectName().isEmpty() ? QByteArray::number(n) : QByteArray(" ").append(toolbar->objectName().toUtf8()));
+        const QString groupName = toolbar->objectName().isEmpty() ? QStringLiteral("Toolbar%1").arg(n) : (QStringLiteral("Toolbar ") + toolbar->objectName());
 
-        KConfigGroup toolbarGroup(&cg, groupName.constData());
+        KConfigGroup toolbarGroup(&cg, groupName);
         toolbar->applySettings(toolbarGroup);
         n++;
     }
@@ -803,20 +763,6 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &_cg)
     d->letDirtySettings = oldLetDirtySettings;
 }
 
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-void KMainWindow::restoreWindowSize(const KConfigGroup &cg)
-{
-    KWindowConfig::restoreWindowSize(windowHandle(), cg);
-}
-#endif
-
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-void KMainWindow::saveWindowSize(KConfigGroup &cg) const
-{
-    KWindowConfig::saveWindowSize(windowHandle(), cg);
-}
-#endif
-
 void KMainWindow::setSettingsDirty()
 {
     Q_D(KMainWindow);
@@ -899,6 +845,7 @@ void KMainWindow::saveAutoSaveSettings()
     // qDebug(200) << "KMainWindow::saveAutoSaveSettings -> saving settings";
     saveMainWindowSettings(d->autoSaveGroup);
     d->autoSaveGroup.sync();
+    d->autoSaveStateGroup().sync();
     d->settingsDirty = false;
 }
 
@@ -981,14 +928,14 @@ void KMainWindowPrivate::_k_slotSettingsChanged(int category)
 void KMainWindowPrivate::_k_slotSaveAutoSaveSize()
 {
     if (autoSaveGroup.isValid()) {
-        KWindowConfig::saveWindowSize(q->windowHandle(), autoSaveGroup);
+        KWindowConfig::saveWindowSize(q->windowHandle(), autoSaveStateGroup());
     }
 }
 
 void KMainWindowPrivate::_k_slotSaveAutoSavePosition()
 {
     if (autoSaveGroup.isValid()) {
-        KWindowConfig::saveWindowPosition(q->windowHandle(), autoSaveGroup);
+        KWindowConfig::saveWindowPosition(q->windowHandle(), autoSaveStateGroup());
     }
 }
 
@@ -1036,3 +983,4 @@ QString KMainWindow::dbusName() const
 
 #include "kmainwindow.moc"
 #include "moc_kmainwindow.cpp"
+#include "moc_kmainwindow_p.cpp"
