@@ -52,11 +52,11 @@
  * A helper function that takes a list of KActionCollection* and converts it
  * to KCommandBar::ActionGroup
  */
-static QVector<KCommandBar::ActionGroup> actionCollectionToActionGroup(const std::vector<KActionCollection *> &actionCollections)
+static QList<KCommandBar::ActionGroup> actionCollectionToActionGroup(const std::vector<KActionCollection *> &actionCollections)
 {
     using ActionGroup = KCommandBar::ActionGroup;
 
-    QVector<ActionGroup> actionList;
+    QList<ActionGroup> actionList;
     actionList.reserve(actionCollections.size());
 
     for (const auto collection : actionCollections) {
@@ -133,7 +133,7 @@ public:
 
     bool commandBarEnabled = true;
     // Last executed actions in command bar
-    QVector<QString> lastExecutedActions;
+    QList<QString> lastExecutedActions;
 
     bool showHelpMenu : 1;
     QSize defaultSize;
@@ -188,7 +188,7 @@ KXmlGuiWindow::KXmlGuiWindow(QWidget *parent, Qt::WindowFlags flags)
     });
     a->setIcon(QIcon::fromTheme(QStringLiteral("search")));
     a->setText(i18n("Find Action…"));
-    actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_I));
+    KActionCollection::setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_I));
 }
 
 QAction *KXmlGuiWindow::toolBarMenuAction()
@@ -260,7 +260,7 @@ KXMLGUIFactory *KXmlGuiWindow::guiFactory()
 void KXmlGuiWindow::configureToolbars()
 {
     Q_D(KXmlGuiWindow);
-    KConfigGroup cg(KSharedConfig::openConfig(), "");
+    KConfigGroup cg(KSharedConfig::openConfig(), QString());
     saveMainWindowSettings(cg);
     if (!d->toolBarEditor) {
         d->toolBarEditor = new KEditToolBar(guiFactory(), this);
@@ -277,7 +277,7 @@ void KXmlGuiWindow::saveNewToolbarConfig()
     guiFactory()->removeClient(this);
     guiFactory()->addClient(this);
 
-    KConfigGroup cg(KSharedConfig::openConfig(), "");
+    KConfigGroup cg(KSharedConfig::openConfig(), QString());
     applyMainWindowSettings(cg);
 }
 
@@ -487,13 +487,6 @@ void KXmlGuiWindow::applyMainWindowSettings(const KConfigGroup &config)
     }
 }
 
-// TODO KF6: change it to "using KXMLGUIBuilder::finalizeGUI;" in the header
-// and remove the reimplementation
-void KXmlGuiWindow::finalizeGUI(KXMLGUIClient *client)
-{
-    KXMLGUIBuilder::finalizeGUI(client);
-}
-
 void KXmlGuiWindow::checkAmbiguousShortcuts()
 {
     QMap<QString, QAction *> shortcuts;
@@ -556,9 +549,9 @@ void KXmlGuiWindow::setCommandBarEnabled(bool showCommandBar)
      */
     auto cmdBarAction = actionCollection()->action(QStringLiteral("open_kcommand_bar"));
     if (showCommandBar) {
-        actionCollection()->setDefaultShortcut(cmdBarAction, Qt::CTRL | Qt::ALT | Qt::Key_I);
+        KActionCollection::setDefaultShortcut(cmdBarAction, Qt::CTRL | Qt::ALT | Qt::Key_I);
     } else {
-        actionCollection()->setDefaultShortcut(cmdBarAction, {});
+        KActionCollection::setDefaultShortcut(cmdBarAction, {});
     }
 
     Q_D(KXmlGuiWindow);
